#
# Author: 
#
# Base class for squares on a 2D game board. A cell doesn't need to know
#    exactly where it is on the board, but it does need to know what to
#    draw for itself.
# 

import picture
import StdDraw

class Cell:
    
    # Create a new cell in the dungeon with the specified image.
    # The Cell base class represents an impassable part of the dungeon.
    def __init__(self, image=""):
        self.image = image
        self.pic = picture.Picture(image)

    # Attempts to add the specified item to this cell.
    # Since the Cell class is impassable, it can never store items.
    # Returns true if item was added, false otherwise.
    def attemptToAdd(self, item):
        return False

    # Attempt to move the specified hero to this location.
    # Since the Cell class is impassable, this always fails.
    def attemptToMove(self, hero):
        return False
    
    # Draw at the specified position in the dungeon.
    # NOTE: x and y are indexes in the dungeon, NOT the StdDraw drawing location.  
    def draw(self, config, x, y):
        StdDraw.picture(self.pic, (x + 0.5) * config.cellPixels(), (y + 0.5) * config.cellPixels())

    # Check if this Cell contains the specified type of item.
    # Since a Cell can't contain an item, this is always false.
    def containsItem(self, item):
        ##### YOUR CODE HERE #####

#
# Test program for Cell.
#    You need not change this code at this time,
#    but feel free to change for your own testing needs.
#
# To run this code and test your class, type "python Cell.py" at the
#    command prompt. Your output should be exactly like what is shown
#    on the assignment page.
#

if __name__ == "__main__":

    import Config

    # The config object stores defaults for sizes, sounds, and images
    config = Config.Config()
        
    # Fake a dungeon that is 3 x 3
    WIDTH = 3
    HEIGHT = 3
    StdDraw.setCanvasSize(WIDTH * config.cellPixels(), HEIGHT * config.cellPixels())
    StdDraw.setXscale(0, WIDTH * config.cellPixels())
    StdDraw.setYscale(0, HEIGHT * config.cellPixels())
        
    # Draw a wall at various locations 
    wall = Cell(config.wallImage())
    wall.draw(config, 0, 0)
    wall.draw(config, 1, 1)
        
    # Wall with a different image
    wall2 = Cell(config.passageImage())
    wall2.draw(config, 2, 2)

    StdDraw.show(2000)
