#
# Author: 
#
# Derived class for squares on a 2D game board. A CellPassage doesn't need to know
#    exactly where it is on the board, but it does need to know if it
#    contains an item, and what that item is. It must be able to add items
#    draw itself, and move a hero into itself.
# 

from Item import Item
from Cell import Cell
from Config import Config
import StdDraw
import picture

class CellPassage(Cell):
    
    # Create a new cell in the dungeon with the specified image.
    # The CellPassage class represents a passable part of the dungeon.
    def __init__(self, image):
        super().__init__(image)
        self.item = Item.NONE

    # Check if this Cell contains the specified type of item.
    def containsItem(self, item):
        ##### YOUR CODE HERE #####
    
    # Attempts to add the specified item to this cell.
    # A CellPassage can store at most one item.
    # Returns true if item was added, false otherwise.
    def attemptToAdd(self, item):
        if self.item == Item.NONE:
            self.item = item
            return True
        else:
            return False

    # Attempt to move the specified hero to this location.
    # Also collect any item present at this location.
    # Since the CellPassage class is always passable, this always returns true.
    def attemptToMove(self, hero):
        if self.item != Item.NONE:
            hero.collectItem(self.item)
            self.item = Item.NONE
        return True
    
    # Draw at the specified position in the dungeon.
    # Also draws any item contained at this location.
    # NOTE: x and y are indexes in the dungeon, NOT the StdDraw drawing location.
    def draw(self, config, x, y):
        super().draw(config, x, y)
        if self.item != Item.NONE:
            image = config.mapItemToImage(self.item)
            if len(image) > 0:
                StdDraw.picture(picture.Picture(image), (x + 0.5) * config.cellPixels(), (y + 0.5) * config.cellPixels())

#
# Test program for CellPassage.
#    You need not change this code at this time,
#    but feel free to change for your own testing needs.
#
# To run this code and test your class, type "python CellPasage.py" at the
#    command prompt. Your output should be exactly like what is shown
#    on the assignment page.
#

if __name__ == "__main__":
    # The config object stores defaults for sizes, sounds, and images
    config = Config()
        
    # Fake a dungeon that is 3 x 3
    WIDTH = 3
    HEIGHT = 3
    StdDraw.setCanvasSize(WIDTH * config.cellPixels(), HEIGHT * config.cellPixels())
    StdDraw.setXscale(0, WIDTH * config.cellPixels())
    StdDraw.setYscale(0, HEIGHT * config.cellPixels())
        
    # A normal passage 
    passage = CellPassage(config.passageImage())
    passage.draw(config, 0, 0)
    print("Adding gem to passage,  result = %5s" %(str(passage.attemptToAdd(Item.GEM))))
    passage.draw(config, 0, 1)
    print("Adding gem to passage,  result = %5s" %(str(passage.attemptToAdd(Item.GEM))))
    print("Adding key to passage,  result = %5s" %(str(passage.attemptToAdd(Item.KEY))))

    # Create another passage and add a key
    passage2 = CellPassage(config.passageImage())
    print("Adding key to passage2, result = %5s" %(str(passage2.attemptToAdd(Item.KEY))))
    passage2.draw(config, 0, 2)
        
    # A secret passage
    secret = CellPassage(config.wallImage())
    secret.draw(config, 1, 0)
    print("Adding key to secret,   result = %5s" %(str(secret.attemptToAdd(Item.KEY))))
    secret.draw(config, 1, 1)
    print("Adding gem to passage,  result = %5s" %(str(secret.attemptToAdd(Item.GEM))))
    print("Adding key to passage,  result = %5s" %(str(secret.attemptToAdd(Item.KEY))))

    # Create another secret passage and add a key
    secret2 = CellPassage(config.wallImage())
    print("Adding key to secret2,  result = %5s" %(str(secret2.attemptToAdd(Item.KEY))))
    secret2.draw(config, 1, 2)

    StdDraw.show(2000)
