#
# Name        :
# Description :
#

import picture

class Cell:
    
    # Create a new cell in the dungeon with the specified image.
    # The Cell base class represents an impassable part of the dungeon.
    def __init__(self, image=""):
        self.image = image
        self.pic = picture.Picture(image)

    # Attempts to add the specified item to this cell.
    # Since the Cell class is impassable, it can never store items.
    # Returns true if item was added, false otherwise.
    def attemptToAdd(self, item)
        return False

    # Attempt to move the specified hero to this location.
    # Since the Cell class is impassable, this always fails.
    def attemptToMove(self, hero):
        return False
    
    # Draw at the specified position in the dungeon.
    # NOTE: x and y are indexes in the dungeon, NOT the StdDraw drawing location.  
    def draw(self, config, x, y):
        StdDraw.picture(self.pic, (x + 0.5) * config.cellPixels(), (y + 0.5) * config.cellPixels())

# Test program for Cell, feel free to change for your own testing needs
if __name__ == "__main__":
    # The config object stores defaults for sizes, sounds, and images
    config = new Config()
        
    # Fake a dungeon that is 3 x 3
    WIDTH = 3
    HEIGHT = 3
    StdDraw.setCanvasSize(WIDTH * config.cellPixels(), HEIGHT * config.cellPixels())
    StdDraw.setXscale(0, WIDTH * config.cellPixels())
    StdDraw.setYscale(0, HEIGHT * config.cellPixels())
        
    # Draw a wall at various locations 
    wall = Cell(config.wallImage())
    wall.draw(config, 0, 0)
    wall.draw(config, 1, 1)
        
    # Wall with a different image
    wall2 = new Cell(config.passageImage())
    wall2.draw(config, 2, 2)
