#
# Author: 
#
# Class that defines the 2D grid that is the dungeon.
# 

from Cell import Cell
from CellPassage import CellPassage
from CellDoor import CellDoor
from CellRock import CellRock
from Hero import Hero
from Action import Action
from Config import Config
from Item import Item
import random
import StdAudio
import StdDraw

class Dungeon:
    
    # Construct a new dungeon of the specified size.
    # NOTE: The dungeon starts out completely empty and won't be usable 
    # until other methods have been run the constructed object:
    #  1) set() to initialize each Cell in the dungeons 2D array
    #  2) addHero() to put a hero in the dungeon
    #  3) addItem() to add keys and gems to the dungeon   
    def __init__(self, config, width, height):
        self.config = config
        self.map = [[Cell(self.config.passageImage()) for i in range(height)] for j in range(width)]
        self.hero = None
     
    # Returns the width of this dungeon
    def getWidth(self):
        ##### YOUR CODE HERE #####
    
    # Returns the height of this dungeon
    def getHeight(self):
        ##### YOUR CODE HERE #####

    # Adds the specified hero to the dungeon
    def addHero(self, hero):
        self.hero = hero
    
    # Setup a given grid location based on a string:
    #  "W" = wall
    #  "S" = secret passage
    #  "D" = closed door
    #  "O" = open door
    #  "-" = dirt floor
    #  "R" = rock
    def set(self, cellX, cellY, str):
        if str == "W":
            # Impassable wall
            self.map[cellX][cellY] = Cell(self.config.wallImage())
        elif str ==  "S":
            # Secret passage
            self.map[cellX][cellY] = CellPassage(self.config.wallImage())
        elif str == "-":
            # Open passageway
            self.map[cellX][cellY] = CellPassage(self.config.passageImage())
        elif str == "D":
            # Locked door
            self.map[cellX][cellY] = CellDoor(self.config.openDoorImage(), self.config.closedDoorImage(), True)
        elif str == "O":
            # Open door
            self.map[cellX][cellY] = CellDoor(self.config.openDoorImage(), self.config.closedDoorImage(), False)
        ##### YOUR CODE HERE #####
              
    # Add the specified item to a random location in the dungeon.
    # The item can only be added to a cell that is passable (i.e.
    # not a wall or a locked door). The location must not already
    # have an item and items can't be added on top of the hero.     
    def addItem(self, item):
        found = False
        counter = 0
        while not found and counter < 100:
            counter += 1
            x = random.randint(0, len(self.map)-1)
            y = random.randint(0, len(self.map[0])-1)
            
            # First make sure not on top of the hero
            if (x != self.hero.getX()) or (y != self.hero.getY()):
                #print(x, y)
                if self.map[x][y].attemptToAdd(item):
                    found = True
    
    # Make the Hero execute the specified action.
    # Currently this is attempting to move north, south, east, or west.
    # If the hero succeeds in moving, play the walking sound.
    # If the action would take the hero into an impassable cell OR 
    # off the dungeon grid, play the hit wall sound.
    def execute(self, action):
        x = self.hero.getX()
        y = self.hero.getY()
        
        if action.name == "NORTH":
            y += 1
        elif action.name == "SOUTH":
            y -= 1
        elif action.name == "EAST":
            x += 1
        elif action.name == "WEST":
            x -= 1
        ##### YOUR CODE HERE #####
        
        # Make sure we are still on the grid
        # Attempt to move to the cell, only update the Hero's position if successful
        if x >= 0 and x < len(self.map) and y >= 0 and y < len(self.map[0]) and self.map[x][y].attemptToMove(self.hero):
            StdAudio.playFile(self.config.walkSound())
            self.hero.setLocation(x, y)
        else:
            StdAudio.playFile(self.config.hitWallSound())
        return True

    
    # Draw all the cell tiles that make up the dungeon.
    # Also draws the hero.
    def draw(self):
        for x in range(0, len(self.map)):
            for y in range(0, len(self.map[0])):
                self.map[x][y].draw(self.config, x, y)
        self.hero.draw()
        # Display number of items hero has collected
        ##### YOUR CODE HERE #####

    # Return a count of the number of a specified item that are currently in the dungeon.
    def getCount(self, item):
        ##### YOUR CODE HERE #####

#
# Test program for Dungeon.
#    You need not change this code at this time,
#    but feel free to change for your own testing needs.
#
# To run this code and test your class, type "python Dungeon.py" at the
#    command prompt. Your output should be exactly like what is shown
#    on the assignment page.
#

if __name__ == "__main__":

    # The config object stores defaults for sizes, sounds, and images
    config = Config()

    # Setup a fake 4 x 3 dungeon
    WIDTH = 4
    HEIGHT = 3
    dungeon = Dungeon(config, WIDTH, HEIGHT)
    StdDraw.setCanvasSize(WIDTH * config.cellPixels(), HEIGHT * config.cellPixels())
    StdDraw.setXscale(0, WIDTH * config.cellPixels())
    StdDraw.setYscale(0, HEIGHT * config.cellPixels())

    # Create a dungeon like:
    #  W--W
    #  O---
    #  WDW-
    dungeon.set(0, 0, "W")
    dungeon.set(1, 0, "D")
    dungeon.set(2, 0, "W")
    dungeon.set(3, 0, "-")
        
    dungeon.set(0, 1, "O")
    dungeon.set(1, 1, "-")
    dungeon.set(2, 1, "-")
    dungeon.set(3, 1, "-")
        
    dungeon.set(0, 2, "W")
    dungeon.set(1, 2, "-")
    dungeon.set(2, 2, "-")
    dungeon.set(3, 2, "W")

    hero = Hero(config, 1, 1)
    dungeon.addHero(hero)
        
    # Add 3 keys and 3 gems at random locations
    for i in range(0,3):
        dungeon.addItem(Item.KEY)
        dungeon.addItem(Item.GEM)
        
    # Draw the sample dungeon
    dungeon.draw()

    StdDraw.show(5000)
