import unittest
from CellDoor import CellDoor
from CellPassage import CellPassage
from Item import Item
import Hero
import Config
import picture
import StdDraw

class CellDoorTestCase(unittest.TestCase):

    def setUp(self):

        # The config object stores defaults for sizes, sounds, and images
        self.config = Config.Config()
        
        # Fake a dungeon that is 3 x 3
        WIDTH = 3
        HEIGHT = 3
        #StdDraw.setCanvasSize(WIDTH * self.config.cellPixels(), HEIGHT * self.config.cellPixels())
        #StdDraw.setXscale(0, WIDTH * self.config.cellPixels())
        #StdDraw.setYscale(0, HEIGHT * self.config.cellPixels())
        
        # Create a door that is initially locked
        self.door = CellDoor("door_open.png", "door_closed.png", True)
        self.door.draw(self.config, 0, 0)
        
        # Create a door that is initially unlocked
        self.door2 = CellDoor("door_open.png", "door_closed.png", False)
        self.door2.draw(self.config, 1, 0)
        

    def test_add_to_closed(self):
        self.assertFalse(self.door.attemptToAdd(Item.GEM))
        self.assertFalse(self.door.attemptToAdd(Item.KEY))

    def test_open(self):
        self.door.open()
        self.door.draw(self.config, 0, 1)

    def test_add_to_open(self):
        self.door.open()
        self.assertTrue(self.door.attemptToAdd(Item.GEM))

    def test_add_to_full(self):
        self.assertFalse(self.door.attemptToAdd(Item.KEY))
        self.door.draw(self.config, 0, 2)

    def test_open_add_add(self):
        self.door2.open()
        self.door2.draw(self.config, 1, 1)
        self.assertTrue(self.door2.attemptToAdd(Item.KEY))
        self.assertFalse(self.door2.attemptToAdd(Item.GEM))
        self.door2.draw(self.config, 1, 2)



if __name__ == '__main__':
    unittest.main()
    StdDraw.show(2000)
